function Chord_Transcription(fileInput,dirOutput)
%  Chord_Transcription(fileInput,dirOutput)
%
%  This function is the algorithm submitted for MIREX 2009 and refered as
%  OGF1 (maj-min).
%
%  This function calculates chord transcriptions (major and minor) for the 
%  audio files listed in the text file 'fileInput' and save them as text
%  files in the 'dirOutput' directory.
%
%  If no output directory is provided, the text files are saved in the
%  directory containing the audio file.
%
%   Compulsory input:
%   * fileInput: path to the text file containing the paths to the audio
%   files
%
%   Optional input:
%   * dirOuput: directory where the text transcriptions are to be stored
%
%
%   Main reference (available at http://www.tsi.enst.fr/~oudre/):
%   Oudre L., Grenier Y., Fvotte C., "Chord recognition by fitting 
%   rescaled chroma vectors to chord templates", 2009.
%
%   Copyright (C) July 2009  L.OUDRE
%   Inquiries, bug report: laurent.oudre@telecom-paristech.fr
%
%   This program is free software; you can redistribute it and/or modify
%   it under the terms of the GNU General Public License as published by
%   the Free Software Foundation; either version 2 of the License, or
%   (at your option) any later version.
%
%   This program is distributed in the hope that it will be useful,
%   but WITHOUT ANY WARRANTY; without even the implied warranty of
%   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%   GNU General Public License for more details.
%
%   You should have received a copy of the GNU General Public License
%   along with this program; if not, write to the Free Software
%   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
%   USA




%% Parameters
mode=0;
K={'maj','min','7'};
harmoniques=1;
distance={'kl2'};
L=17;
lissage=2;

%% Main program
tic


[songs] = textread(fileInput, '%s','delimiter','\n');
N_song=length(songs);

for i_song=1:N_song
    [pathstr, name, ext] = fileparts(songs{i_song});
    fprintf(1,['Transcription of ' name '...'])

    
    [C,t,silences] = compute_chroma(songs{i_song},-66); 
    [path]=transcription(C,mode,K,harmoniques,distance,L,lissage); 
        
    path(silences)=24;

        
    if nargin<2
        save_transcription([songs{i_song} '.txt'],t,path);
    else
        save_transcription([dirOutput name ext '.txt'],t,path);
    end

       
   fprintf(1,'Done') 
   fprintf(1,'\n')
end

tcomputation=toc;

fprintf(1,['Completed in ' num2str(tcomputation) 's'])
fprintf(1,'\n')


%% function save_transcription(newfile,times,chords)
%%% This function saves a chord transcription as a text file

function save_transcription(newfile,times,chords)
fid = fopen(newfile,'wt');
for j = 1:length(times)
    fprintf(fid,'%s \n',char(strcat(num2str(times(j),'%12.6f'),{' '},num2str(chords(j),'%d'))));
end
fclose(fid);










